==> haskell-glib-0.13.11.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-glib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   glib
version:                0.13.11.0
visibility:             public
id:                     glib-0.13.11.0-4oyX2pERoLrHuBvxWitH1B
key:                    glib-0.13.11.0-4oyX2pERoLrHuBvxWitH1B
license:                LGPL-2.1-only
copyright:              (c) 2001-2010 The Gtk2Hs Team
maintainer:             gtk2hs-users@lists.sourceforge.net
author:                 Axel Simon, Duncan Coutts
stability:              stable
homepage:               http://projects.haskell.org/gtk2hs/
synopsis:               Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.

category:               System
abi:                    23e1abd955fe9ce0f9b91b934104b46e
exposed:                True
exposed-modules:
    System.Glib System.Glib.Attributes System.Glib.FFI
    System.Glib.Flags System.Glib.GDateTime System.Glib.GError
    System.Glib.GList System.Glib.GObject System.Glib.GParameter
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.MainLoop
    System.Glib.Properties System.Glib.Signals System.Glib.StoreValue
    System.Glib.Types System.Glib.UTFString System.Glib.Utils

import-dirs:            /usr/lib/ghc-9.4.8/site-local/glib-0.13.11.0
library-dirs:           /usr/lib/ghc-9.4.8/site-local/glib-0.13.11.0
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/glib-0.13.11.0
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-glib
hs-libraries:           HSglib-0.13.11.0-4oyX2pERoLrHuBvxWitH1B
extra-libraries:        gobject-2.0 glib-2.0
extra-libraries-static: gobject-2.0 glib-2.0 m sysprof-capture-4 pcre2-8 ffi
include-dirs:
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6

depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    utf8-string-1.0.2-EQXJBdOxi5qEemJFLwYYhw

haddock-interfaces:     /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html:           /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glib-0.13.11.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-glib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   glib
version:                0.13.11.0
visibility:             public
id:                     glib-0.13.11.0-1MwE6kbHoAkIBHJNwVPRER
key:                    glib-0.13.11.0-1MwE6kbHoAkIBHJNwVPRER
license:                LGPL-2.1-only
copyright:              (c) 2001-2010 The Gtk2Hs Team
maintainer:             gtk2hs-users@lists.sourceforge.net
author:                 Axel Simon, Duncan Coutts
stability:              stable
homepage:               http://projects.haskell.org/gtk2hs/
synopsis:               Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.

category:               System
abi:                    e9591294af0583f0df6cbfd6f21c6708
exposed:                True
exposed-modules:
    System.Glib System.Glib.Attributes System.Glib.FFI
    System.Glib.Flags System.Glib.GDateTime System.Glib.GError
    System.Glib.GList System.Glib.GObject System.Glib.GParameter
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.MainLoop
    System.Glib.Properties System.Glib.Signals System.Glib.StoreValue
    System.Glib.Types System.Glib.UTFString System.Glib.Utils

import-dirs:            /usr/lib/ghc-9.4.8/site-local/glib-0.13.11.0
library-dirs:           /usr/lib/ghc-9.4.8/site-local/glib-0.13.11.0
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/glib-0.13.11.0
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-glib
hs-libraries:           HSglib-0.13.11.0-1MwE6kbHoAkIBHJNwVPRER
extra-libraries:        gobject-2.0 glib-2.0
extra-libraries-static: gobject-2.0 glib-2.0 m sysprof-capture-4 pcre2-8 ffi
include-dirs:
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6

depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    utf8-string-1.0.2-4puy9i6JhHg6bynwSjfiUA

haddock-interfaces:     /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html:           /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
